==> jc-1.4.0.tar.gz: polyglot/lex/NumericLiteral.h <==
// public abstract class polyglot.lex.NumericLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class bcf65095391d700b polyglot_lex_NumericLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_NumericLiteral_H_
#define _JC_polyglot_lex_NumericLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_NumericLiteral$sub_refs	_jc_polyglot_lex_NumericLiteral$sub_refs;
typedef struct _jc_polyglot_lex_NumericLiteral$sub_nonrefs	_jc_polyglot_lex_NumericLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_NumericLiteral$refs	_jc_polyglot_lex_NumericLiteral$refs;
typedef struct _jc_polyglot_lex_NumericLiteral$nonrefs	_jc_polyglot_lex_NumericLiteral$nonrefs;
typedef struct _jc_polyglot_lex_NumericLiteral$object	_jc_polyglot_lex_NumericLiteral$object;

typedef const struct _jc_polyglot_lex_NumericLiteral$vmethods	_jc_polyglot_lex_NumericLiteral$vmethods;
typedef const struct _jc_polyglot_lex_NumericLiteral$vtable	_jc_polyglot_lex_NumericLiteral$vtable;
typedef const struct _jc_polyglot_lex_NumericLiteral$vtype	_jc_polyglot_lex_NumericLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_NumericLiteral$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *, struct _jc_polyglot_util_Position$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Number$object *_jc_polyglot_lex_NumericLiteral$method$getValue$3ae6b6da20107e08(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_NumericLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_NumericLiteral$method_info$getValue$3ae6b6da20107e08;
extern _jc_method _jc_polyglot_lex_NumericLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_NumericLiteral$vmethods {
	struct _jc_java_lang_Number$object	*(*getValue$3ae6b6da20107e08)(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *);
};

// Vtable
struct _jc_polyglot_lex_NumericLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NumericLiteral$vmethods	polyglot_lex_NumericLiteral;
};

// Vtype
struct _jc_polyglot_lex_NumericLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_NumericLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_NumericLiteral$sub_refs {
	struct _jc_java_lang_Number$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_NumericLiteral$refs {
    _jc_polyglot_lex_NumericLiteral$sub_refs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_NumericLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_NumericLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NumericLiteral$sub_nonrefs	polyglot_lex_NumericLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_NumericLiteral$object {
	_jc_polyglot_lex_NumericLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_NumericLiteral$vtype	*vtype;
	_jc_polyglot_lex_NumericLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_NumericLiteral$vtype _jc_polyglot_lex_NumericLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_NumericLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_NumericLiteral$class_object;

#endif	/* _JC_polyglot_lex_NumericLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/NumericLiteral.h <==
// public abstract class polyglot.lex.NumericLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class bcf65095391d700b polyglot_lex_NumericLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_NumericLiteral_H_
#define _JC_polyglot_lex_NumericLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_NumericLiteral$sub_refs	_jc_polyglot_lex_NumericLiteral$sub_refs;
typedef struct _jc_polyglot_lex_NumericLiteral$sub_nonrefs	_jc_polyglot_lex_NumericLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_NumericLiteral$refs	_jc_polyglot_lex_NumericLiteral$refs;
typedef struct _jc_polyglot_lex_NumericLiteral$nonrefs	_jc_polyglot_lex_NumericLiteral$nonrefs;
typedef struct _jc_polyglot_lex_NumericLiteral$object	_jc_polyglot_lex_NumericLiteral$object;

typedef const struct _jc_polyglot_lex_NumericLiteral$vmethods	_jc_polyglot_lex_NumericLiteral$vmethods;
typedef const struct _jc_polyglot_lex_NumericLiteral$vtable	_jc_polyglot_lex_NumericLiteral$vtable;
typedef const struct _jc_polyglot_lex_NumericLiteral$vtype	_jc_polyglot_lex_NumericLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_NumericLiteral$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *, struct _jc_polyglot_util_Position$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Number$object *_jc_polyglot_lex_NumericLiteral$method$getValue$3ae6b6da20107e08(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_NumericLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_NumericLiteral$method_info$getValue$3ae6b6da20107e08;
extern _jc_method _jc_polyglot_lex_NumericLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_NumericLiteral$vmethods {
	struct _jc_java_lang_Number$object	*(*getValue$3ae6b6da20107e08)(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_NumericLiteral$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_NumericLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_NumericLiteral$vmethods	polyglot_lex_NumericLiteral;
};

// Vtype
struct _jc_polyglot_lex_NumericLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_NumericLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_NumericLiteral$sub_refs {
	struct _jc_java_lang_Number$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_NumericLiteral$refs {
    _jc_polyglot_lex_NumericLiteral$sub_refs	polyglot_lex_NumericLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_NumericLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_NumericLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_NumericLiteral$sub_nonrefs	polyglot_lex_NumericLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_NumericLiteral$object {
	_jc_polyglot_lex_NumericLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_NumericLiteral$vtype	*vtype;
	_jc_polyglot_lex_NumericLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_NumericLiteral$vtype _jc_polyglot_lex_NumericLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_NumericLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_NumericLiteral$class_object;

#endif	/* _JC_polyglot_lex_NumericLiteral_H_ */
